<?php

namespace Me\Test\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Me\Test\Interfaces\TestingRepositoryInterface;

class TestingPublicController extends BaseController
{
    // use TestingWorkflow;

    /**
     * Constructor.
     *
     * @param type \Me\Testing\Interfaces\TestingRepositoryInterface $testing
     *
     * @return type
     */
    public function __construct(TestingRepositoryInterface $testing)
    {
        $this->repository = $testing;
        parent::__construct();
    }

    /**
     * Show testing's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $testings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$test::$testing.names'))
            ->view('$test::public.testing.index')
            ->data(compact('$testings'))
            ->output();
    }

    /**
     * Show testing's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $testings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$test::$testing.names'))
            ->view('$test::public.testing.index')
            ->data(compact('$testings'))
            ->output();
    }

    /**
     * Show testing.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $testing = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$testing->name . trans('$test::$testing.name'))
            ->view('$test::public.testing.show')
            ->data(compact('$testing'))
            ->output();
    }

}
